@@ -76,5 +76,8 @@ class TopCmd(Command):
 
 
 def top():
-    TopCmd()()
+    cmd = TopCmd()
+    cmd()
+
+
 
