@@ -1,4 +1,4 @@
-from os import environ
+from os import environ, makedirs
 from os.path import expanduser
 from pathlib import Path
 from subprocess import run
@@ -30,6 +30,7 @@ class ConfigCmd(Command):
         path = get_config_path()
         if not path:
             path = Path('~/.config/setux/config.py').expanduser()
+            makedirs(path.parent, exist_ok=True)
             with open(path, 'w') as out:
                 out.write(init_config)
         editor = environ.get('EDITOR','vim')
